@@ -42,4 +42,4 @@
  *   2 = version 4.0/4.1 */
 #undef NCURSES_970530
 
-#undef HAVE_ORBIT
+#undef WITH_SYMBOL_UNDERSCORE
