@@ -15,8 +15,6 @@
 ; License along with this library; if not, write to the Free
 ; Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-(define FLIP-COUNTER 0)
-
 (define (new-game)
   (initialize-playing-area)
   (set-ace-low)
@@ -44,13 +42,13 @@
 
   (deal-cards 8 '(0 2 4 6 0 2 4 6 0 2 4 6))
   (deal-cards-face-up 8 '(0 2 4 6 1))
-  (set! FLIP-COUNTER 0)
+
   (list 6 5)
 )
   
 (define (button-pressed slot-id card-list)
   (and (not (empty-slot? slot-id))
-       (= (list-length card-list) 1)
+       (= (length card-list) 1)
        (or (= slot-id 0) 
 	   (= slot-id 2)
 	   (= slot-id 4) 
@@ -86,22 +84,63 @@
 					    (get-value (car card-list))) )))
        (complete-transaction start-slot card-list end-slot)))
   
-(define (flip-cards-back)
-  (if (not (empty-slot? 9))
-      (begin
-	(add-card! 8 (flip-card (remove-card 9)))
-	(flip-cards-back))))
-
 (define (button-clicked slot-id)
   (and (= slot-id 8)
-      (if (empty-slot? 8)
-	  (and (< FLIP-COUNTER 3)
-	       (set! FLIP-COUNTER (+ 1 FLIP-COUNTER))
-	       (flip-cards-back))
-	  (add-card! 9 (flip-card (remove-card 8))))))
-	      
+       (flip-stock 8 9 2)))
+
+(define (check-to-move orig-slot end-slot above-list top-card)
+  (if (not (null? above-list))
+      (if (eq? (get-value top-card)
+	       (get-value (car above-list)))
+	  (begin
+	    (remove-card orig-slot)
+	    (complete-transaction orig-slot (list top-card) end-slot))
+	  (check-to-move orig-slot end-slot (cdr above-list) top-card))
+      #f))
+  
+
 (define (button-double-clicked slot)
-  #f)
+  (if (and (or (= slot 0)
+	       (= slot 2)
+	       (= slot 4)
+	       (= slot 6)
+	       (= slot 9))
+	   (not (empty-slot? slot)))
+      (begin
+	(let ((top-card (get-top-card slot)))
+	  (if (eq? (get-suit top-card)
+		   (get-suit (car (get-cards 1))))
+	      (begin
+		(remove-card slot)
+		(complete-transaction slot (list top-card) 1))
+	      (if (eq? (get-value top-card)
+		       (get-value (car (reverse (get-cards 1)))))
+		  (cond  ((empty-slot? 3)
+			  (begin
+			    (remove-card slot)
+			    (complete-transaction slot (list top-card) 3)))
+			 ((empty-slot? 5)
+			  (begin
+			    (remove-card slot)
+			    (complete-transaction slot (list top-card) 5)))
+			 (#t
+			  (begin
+			    (remove-card slot)
+			    (complete-transaction slot (list top-card) 7))))
+		  (cond ((and (not (empty-slot? 3))
+			      (eq? (get-suit top-card)
+				   (get-suit (car (get-cards 3)))))
+			 (check-to-move slot 3 (get-cards 1) top-card))
+			((and (not (empty-slot? 5))
+			      (eq? (get-suit top-card)
+				   (get-suit (car (get-cards 5)))))
+			 (check-to-move slot 5 (get-cards 3) top-card))
+			((and (not (empty-slot? 7))
+			      (eq? (get-suit top-card)
+				   (get-suit (car (get-cards 7)))))
+			 (check-to-move slot 7 (get-cards 5) top-card))
+			(#t #f))))))	 
+      #f))
 
 (define (placeable? card slot-id)
   (and (< slot-id 9)
@@ -123,21 +162,26 @@
 		(placeable? (get-top-card (car id-list)) 1))
 	   (get-valid-move (cdr id-list)))))
 
-(define (game-over not-used)
+(define (game-over)
   (or (and (< FLIP-COUNTER 3)
 	   (not (empty-slot? 9)))
       (not (empty-slot? 8))
       (get-valid-move '(0 2 4 6 9))))
 
-(define (game-won not-used)
-  (and (= 13 (list-length (get-cards 1)))
-       (= 13 (list-length (get-cards 3)))
-       (= 13 (list-length (get-cards 5)))
-       (= 13 (list-length (get-cards 7)))))
+(define (game-won)
+  (and (= 13 (length (get-cards 1)))
+       (= 13 (length (get-cards 3)))
+       (= 13 (length (get-cards 5)))
+       (= 13 (length (get-cards 7)))))
 
-(define (get-hint not-used)
+(define (get-hint)
   (or (get-valid-move '(0 2 4 6 9))
       (list 0 "Deal a new card from the deck"))) ; Should be (list 3 ...)
 
-(set-lambda new-game button-pressed button-released button-clicked button-double-clicked game-over game-won get-hint)
+(define (get-options) #f)
 
+(define (apply-options options) #f)
+
+(define (timeout) #f)
+
+(set-lambda new-game button-pressed button-released button-clicked button-double-clicked game-over game-won get-hint get-options apply-options timeout)
