@@ -19,21 +19,20 @@
 #ifndef PRESS_DATA_H
 #define PRESS_DATA_H
 #include <gtk/gtk.h>
+#include "slot.h"
 
 typedef struct {
   gint xoffset;
   gint yoffset;
   GdkPixmap *moving_pixmap;
   GdkBitmap *moving_mask;
-  gint button_pressed;
   GList* cards;
-  gint slot_id;
-  gint slot_location;
-  gint temporary_partial_hack;
-  gboolean moving;
+  hslot_type hslot;
+  gint cardid;
+  gint status;
   GdkWindow *moving_cards;
 } press_data_type;
 
-void generate_press_data(gint, gint, gint, gint);
+void generate_press_data ();
 
 #endif
