@@ -16,7 +16,8 @@ GnibblesBoni *gnibbles_boni_new ()
 	for (i = 0; i < MAXBONUSES; i++)
 		tmp->bonuses[i] = NULL;
 	tmp->numbonuses = 0;
-	tmp->numleft = 11;
+	tmp->numleft = NUMBONI;
+	tmp->missed = 0;
 
 	return tmp;
 }
@@ -44,6 +45,8 @@ void gnibbles_boni_add_bonus (GnibblesBoni *boni, gint t_x, gint t_y,
 	board[t_x + 1][t_y + 1] = t_type + 'A';
 	gnibbles_bonus_draw (boni->bonuses[boni->numbonuses]);
 	boni->numbonuses++;
+	if (t_type != BONUSREGULAR)
+		gnome_triggers_do (NULL, NULL, "gnibbles", "appear", NULL);
 }
 
 int gnibbles_boni_fake (GnibblesBoni *boni, gint x, gint y)
