@@ -189,6 +189,8 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 	pref_dialog = gnome_property_box_new ();
 	gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog), GTK_WINDOW
 			(window));
+	gtk_window_set_title (GTK_WINDOW (pref_dialog),
+			_("Gnibbles Preferences"));
 	gtk_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
 			GTK_SIGNAL_FUNC (gtk_widget_destroyed), &pref_dialog);
 	gtk_signal_connect (GTK_OBJECT (pref_dialog), "destroy",
@@ -260,7 +262,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 //	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD);
 
-	label2 = gtk_label_new ("Starting level: ");
+	label2 = gtk_label_new (_("Starting level: "));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 	gtk_widget_show (label2);
 	gtk_table_attach (GTK_TABLE (table), label2, 0, 1, 2, 3, GTK_EXPAND |
@@ -289,7 +291,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
 
-	button = gtk_check_button_new_with_label (_("Fake bonuses (fun!)"));
+	button = gtk_check_button_new_with_label (_("Fake bonuses"));
 	gtk_signal_connect (GTK_OBJECT (button), "toggled", GTK_SIGNAL_FUNC
 			(fake_bonus_cb), NULL);
 	gtk_widget_show (button);
@@ -299,7 +301,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				TRUE);
 
-	label2 = gtk_label_new ("Number of players: ");
+	label2 = gtk_label_new (_("Number of players: "));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 	gtk_widget_show (label2);
 	gtk_table_attach (GTK_TABLE (table), label2, 0, 1, 3, 4, GTK_EXPAND |
@@ -322,7 +324,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 			hbox, label);
 
 	for (i = 0; i < NUMWORMS; i++) {
-		sprintf (buffer, "Worm %d", i + 1);
+		sprintf (buffer, _("Worm %d"), i + 1);
 		label = gtk_label_new (buffer);
 		gtk_widget_show (label);
 
@@ -332,7 +334,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 		gtk_widget_show (table);
 
-		label2 = gtk_label_new ("Up:");
+		label2 = gtk_label_new (_("Up:"));
 		gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 		gtk_widget_show (label2);
 		gtk_table_attach (GTK_TABLE (table), label2, 0, 1, 0, 1,
@@ -350,7 +352,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 				0, 0,
 				0, 0);
 
-		label2 = gtk_label_new ("Down:");
+		label2 = gtk_label_new (_("Down:"));
 		gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 		gtk_widget_show (label2);
 		gtk_table_attach (GTK_TABLE (table), label2, 2, 3, 0, 1,
@@ -368,7 +370,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 				0, 0,
 				0, 0);
 
-		label2 = gtk_label_new ("Left:");
+		label2 = gtk_label_new (_("Left:"));
 		gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 		gtk_widget_show (label2);
 		gtk_table_attach (GTK_TABLE (table), label2, 0, 1, 1, 2,
@@ -386,7 +388,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 				0, 0,
 				0, 0);
 
-		label2 = gtk_label_new ("Right:");
+		label2 = gtk_label_new (_("Right:"));
 		gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 		gtk_widget_show (label2);
 		gtk_table_attach (GTK_TABLE (table), label2, 2, 3, 1, 2,
@@ -404,7 +406,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 				0, 0,
 				0, 0);
 
-		label2 = gtk_label_new ("Color:");
+		label2 = gtk_label_new (_("Color:"));
 		gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 		gtk_widget_show (label2);
 		gtk_table_attach (GTK_TABLE (table), label2, 0, 1, 2, 3,
@@ -413,7 +415,7 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 
 		omenu = gtk_option_menu_new ();
 		menu = gtk_menu_new ();
-		menuitem = gtk_menu_item_new_with_label ("Red");
+		menuitem = gtk_menu_item_new_with_label (_("Red"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
@@ -425,31 +427,31 @@ void gnibbles_preferences_cb (GtkWidget *widget, gpointer data)
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMGREEN << 2 | i));
-		menuitem = gtk_menu_item_new_with_label ("Blue");
+		menuitem = gtk_menu_item_new_with_label (_("Blue"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMBLUE << 2 | i));
-		menuitem = gtk_menu_item_new_with_label ("Yellow");
+		menuitem = gtk_menu_item_new_with_label (_("Yellow"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMYELLOW << 2 | i));
-		menuitem = gtk_menu_item_new_with_label ("Cyan");
+		menuitem = gtk_menu_item_new_with_label (_("Cyan"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMCYAN << 2 | i));
-		menuitem = gtk_menu_item_new_with_label ("Purple");
+		menuitem = gtk_menu_item_new_with_label (_("Purple"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 				GTK_SIGNAL_FUNC (set_worm_color_cb),
 				(gpointer) (WORMPURPLE << 2 | i));
-		menuitem = gtk_menu_item_new_with_label ("Gray");
+		menuitem = gtk_menu_item_new_with_label (_("Gray"));
 		gtk_widget_show (menuitem);
 		gtk_menu_append (GTK_MENU (menu), menuitem);
 		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
