@@ -6,6 +6,8 @@
 /* Exported functions                                                 */
 /**********************************************************************/
 gboolean create_game_menus();
+void really_exit_cb (GtkWidget *, gpointer);
+void exit_cb (GtkWidget *, gpointer);
 /**********************************************************************/
 
 
