@@ -26,6 +26,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <config.h>
+#include <dirent.h>
 
 GdkImlibImage *image;
 GdkPixmap *pix;
@@ -49,9 +50,21 @@ int color_next = -1;
 bool random_block_colors = false;
 bool do_preview = true;
 
-Tetris::Tetris(int cmdlLevel)
-	: paused(false), timeoutId(-1), onePause(false), setupdialog(NULL), 
-		cmdlineLevel(cmdlLevel), doPreviewTmp(do_preview), randomBlocksTmp(random_block_colors)
+char *Tetris::blockPixmapTmp = NULL;
+
+Tetris::Tetris(int cmdlLevel): 
+	paused(false), 
+	timeoutId(-1), 
+	onePause(false), 
+	setupdialog(NULL), 
+	cmdlineLevel(cmdlLevel), 
+	doPreviewTmp(do_preview), 
+	randomBlocksTmp(random_block_colors),
+	blockPixmap(NULL),
+	image(NULL),
+	scoreFrame(NULL),
+	field(NULL),
+	preview(NULL)
 {
 	w = gnome_app_new("gnometris", _("Gnometris"));
   gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
@@ -59,32 +72,30 @@ Tetris::Tetris(int cmdlLevel)
 
 	GnomeUIInfo game_menu[] = 
 	{
-		{ GNOME_APP_UI_ITEM, N_("_New"), "_Start a new game", gameNew, this, NULL, 
-			GNOME_APP_PIXMAP_STOCK, (gpointer)GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL },
-		{ GNOME_APP_UI_ITEM, N_("_Properties..."), NULL, gameProperties, this, NULL,
-			GNOME_APP_PIXMAP_STOCK, (gpointer)GNOME_STOCK_MENU_PROP, 0, (GdkModifierType)0, NULL},
-		{ GNOME_APP_UI_ITEM, N_("_Scores"), NULL, gameTopTen, this, NULL,
-			GNOME_APP_PIXMAP_STOCK, (gpointer)GNOME_STOCK_MENU_SCORES, 0, (GdkModifierType)0, NULL},
-		{ GNOME_APP_UI_ITEM, N_("E_xit"), "E_xit Gnometris", gameQuit, this, NULL, 
-			GNOME_APP_PIXMAP_STOCK, (gpointer)GNOME_STOCK_MENU_EXIT, 'q', GDK_CONTROL_MASK, NULL },
+		GNOMEUIINFO_MENU_NEW_GAME_ITEM(gameNew, this),
+		GNOMEUIINFO_MENU_PREFERENCES_ITEM(gameProperties, this),
+		GNOMEUIINFO_MENU_SCORES_ITEM(gameTopTen, this),
+		GNOMEUIINFO_MENU_EXIT_ITEM(gameQuit, this),
 		GNOMEUIINFO_END
 	};
 
 	GnomeUIInfo help_menu[] = 
 	{
-		{ GNOME_APP_UI_HELP, NULL, NULL, (gpointer)"gnometris", NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, 0, (GdkModifierType)0, NULL},
-		{ GNOME_APP_UI_ITEM, N_("_About Gnometris"), NULL, gameAbout, this, NULL, 
-			GNOME_APP_PIXMAP_STOCK, (gpointer)GNOME_STOCK_MENU_ABOUT, 0, (GdkModifierType)0, NULL },
+		GNOMEUIINFO_HELP((gpointer)"gnometris"),
+		GNOMEUIINFO_MENU_ABOUT_ITEM(gameAbout, this),
 		GNOMEUIINFO_END
 	};
 
 	GnomeUIInfo mainmenu[] = 
 	{
-		{ GNOME_APP_UI_SUBTREE, N_("_Game"), NULL, game_menu, NULL, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, (GdkModifierType)0, NULL },
-		{ GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, help_menu, NULL, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, (GdkModifierType)0, NULL },
+		GNOMEUIINFO_MENU_GAME_TREE(game_menu),
+		GNOMEUIINFO_MENU_HELP_TREE(help_menu),
 		GNOMEUIINFO_END
 	};
 
+	blockPixmap = strdup(gnome_config_get_string_with_default("/gnometris/Properties/BlockPixmap=7blocks.png", NULL));
+	setupPixmap();
+
 	gnome_app_create_menus(GNOME_APP(w), mainmenu);
 
   GtkWidget * hb = gtk_hbox_new(FALSE, 0);
@@ -96,7 +107,7 @@ Tetris::Tetris(int cmdlLevel)
 	gtk_widget_set_events(w, gtk_widget_get_events(w) | GDK_KEY_PRESS_MASK);
 	
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
-  gtk_container_border_width(GTK_CONTAINER(vb1), 10);
+	gtk_container_border_width(GTK_CONTAINER(vb1), 10);
 	gtk_box_pack_start_defaults(GTK_BOX(vb1), field->getWidget());
 	gtk_box_pack_start(GTK_BOX(hb), vb1, 0, 0, 0);
 	field->show();
@@ -104,7 +115,7 @@ Tetris::Tetris(int cmdlLevel)
 	gtk_signal_connect(GTK_OBJECT(w), "event", (GtkSignalFunc)eventHandler, this);
   
 	GtkWidget *vb2 = gtk_vbox_new(FALSE, 0);
-  gtk_container_border_width(GTK_CONTAINER(vb2), 10);
+	gtk_container_border_width(GTK_CONTAINER(vb2), 10);
 	gtk_box_pack_end(GTK_BOX(hb), vb2, 0, 0, 0);
 	
 	preview = new Preview();
@@ -130,6 +141,12 @@ Tetris::~Tetris()
 	delete field;
 	delete preview;
 	delete scoreFrame;
+
+	if (image)
+		gdk_imlib_destroy_image(image);
+
+	if (blockPixmap)
+		free(blockPixmap);
 }
 
 void 
@@ -140,22 +157,79 @@ Tetris::setupdialogDestroy(GtkWidget *widget, void *d)
 	t->setupdialog = NULL;
 }
 
+void
+Tetris::setupPixmap()
+{
+	char *pixname, *fullpixname;
+	
+	pixname = g_copy_strings("gnometris/", blockPixmap, NULL);
+	fullpixname = gnome_unconditional_pixmap_file(pixname);
+	g_free(pixname);
+
+	if (!g_file_exists(fullpixname)) 
+	{
+		printf(_("Could not find the \'%s\' theme for gnometris\n"), fullpixname);
+		exit(1);
+	}
+
+	if(image)
+		gdk_imlib_destroy_image(image);
+
+	image = gdk_imlib_load_image(fullpixname);
+	gdk_imlib_render(image, image->rgb_width, image->rgb_height);
+	pix = gdk_imlib_move_image(image);
+
+	BLOCK_SIZE = image->rgb_height;
+	nr_of_colors = image->rgb_width / BLOCK_SIZE;
+
+	if (field)
+	{
+		field->updateSize();
+		gtk_widget_draw(field->getWidget(), NULL);
+	}
+	
+	if (preview)
+	{
+		preview->updateSize();
+		gtk_widget_draw(preview->getWidget(), NULL);
+	}
+
+	// FIXME: this really sucks, but I can't find a better way to resize 
+	// all widgets after the block pixmap change
+	if (scoreFrame)
+	{
+		int l = scoreFrame->getLevel();
+		scoreFrame->setLevel(l + 1);
+		scoreFrame->setLevel(l);
+	}
+	
+}
+
 void
 Tetris::doSetup(GtkWidget *widget, void *d)
 {
 	Tetris *t = (Tetris*) d;
 	t->cmdlineLevel = 0;
-  t->startingLevel = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(t->sentry));
+	t->startingLevel = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(t->sentry));
 	do_preview = t->doPreviewTmp;
 	random_block_colors = t->randomBlocksTmp;
 	
 	gnome_config_set_int("/gnometris/Properties/StartingLevel", t->startingLevel);
 	gnome_config_set_int("/gnometris/Properties/DoPreview", do_preview);
 	gnome_config_set_int("/gnometris/Properties/RandomBlockColors", random_block_colors);
+	
+	if (t->blockPixmap)
+		free(t->blockPixmap);
+	
+	t->blockPixmap = strdup(blockPixmapTmp);
+	
+	gnome_config_set_string("/gnometris/Properties/BlockPixmap", t->blockPixmap);
+	
 	gnome_config_sync();
 	
 	t->scoreFrame->setLevel(t->startingLevel);
 	setupdialogDestroy(widget, d);
+	t->setupPixmap();
 }
 
 void 
@@ -172,18 +246,69 @@ Tetris::setSelectionBlocks(GtkWidget *widget, void *d)
 	t->randomBlocksTmp = GTK_TOGGLE_BUTTON(widget)->active;
 }
 
+void
+Tetris::setSelection(GtkWidget *widget, void *data)
+{
+	blockPixmapTmp = (char*) data;
+}
+
+void
+Tetris::freeStr(GtkWidget *widget, void *data)
+{
+	free(data);
+}
+
+void
+Tetris::fillMenu(GtkWidget *menu)
+{
+	struct dirent *e;
+	char *dname = gnome_unconditional_pixmap_file("gnometris");
+	DIR *dir;
+  int itemno = 0;
+	
+	dir = opendir (dname);
+
+	if (!dir)
+		return;
+	
+	while ((e = readdir (dir)) != NULL)
+	{
+		GtkWidget *item;
+		char *s = strdup(e->d_name);
+
+		if (!strstr (e->d_name, ".png")) 
+		{
+			free(s);
+			continue;
+		}
+			
+		item = gtk_menu_item_new_with_label(s);
+		gtk_widget_show(item);
+		gtk_menu_append(GTK_MENU(menu), item);
+		gtk_signal_connect(GTK_OBJECT(item), "activate", (GtkSignalFunc) setSelection, s);
+		gtk_signal_connect(GTK_OBJECT(item), "destroy", (GtkSignalFunc) freeStr, s);
+	  
+		if (!strcmp(blockPixmap, s))
+		{
+		  gtk_menu_set_active(GTK_MENU(menu), itemno);
+		}
+		itemno++;
+	}
+	closedir(dir);
+}
+
 int 
 Tetris::gameProperties(GtkWidget *widget, void *d)
 {
-  GtkWidget *allBoxes;
+	GtkWidget *allBoxes;
 	GtkWidget *box, *box2;
 	GtkWidget *button, *label;
 	GtkWidget *frame;
-  GtkObject *adj;
-
+	GtkObject *adj;
+        
 	Tetris *t = (Tetris*) d;
 	
-  if (t->setupdialog) 
+	if (t->setupdialog) 
 		return FALSE;
 
 	t->setupdialog = gtk_window_new(GTK_WINDOW_DIALOG);
@@ -244,6 +369,21 @@ Tetris::gameProperties(GtkWidget *widget, void *d)
 	gtk_box_pack_start(GTK_BOX(box), cb, 0, 0, 0);
 	gtk_widget_show(cb);
 
+	box2 = gtk_hbox_new(FALSE, 0);
+  gtk_container_border_width(GTK_CONTAINER(box2), 10);
+	gtk_box_pack_start(GTK_BOX(box), box2, TRUE, TRUE, 0);
+	label = gtk_label_new(_("Block Pixmap: "));
+	gtk_box_pack_start(GTK_BOX(box2), label, 0, 0, 0);
+	gtk_widget_show(label);
+	GtkWidget *omenu = gtk_option_menu_new();
+	GtkWidget *menu = gtk_menu_new();
+	t->fillMenu(menu);
+	gtk_widget_show(omenu);
+	gtk_option_menu_set_menu(GTK_OPTION_MENU(omenu), menu);
+	gtk_box_pack_end(GTK_BOX(box2), omenu, 0, 0, 0);
+	gtk_box_pack_start(GTK_BOX(box), box2, 0, 0, 0);
+	gtk_widget_show(box2);
+
 	box = gtk_hbox_new(TRUE, 5);
 	gtk_box_pack_start(GTK_BOX(allBoxes), box, TRUE, TRUE, 0);
 	button = gnome_stock_button(GNOME_STOCK_BUTTON_OK);
