@@ -1,5 +1,5 @@
 /*
- * othello.c - Othello support routines for gnothello
+ * othello.c - Othello support routines for iagno
  * written by Ian Peters <ipeters@acm.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -47,11 +47,15 @@ guint heuristic[8][8] = {{9,2,7,8,8,7,2,9},
 			 {2,1,3,4,4,3,1,2},
 			 {9,2,7,8,8,7,2,9}};
 
-guint flip_final_id;
+guint flip_final_id = 0;
+gint flip_final;
 
 extern guint black_computer_level;
 extern guint white_computer_level;
 
+extern gint animate;
+extern gint animate_stagger;
+
 extern guint whose_turn;
 extern guint game_in_progress;
 
@@ -187,8 +191,6 @@ gint move_board(gint8 board[8][8], guint x, guint y, guint me, gint real)
 	gint tmp_x, tmp_y;
 	guint not_me;
 	gint adder = 0, adder_diff = 0;
-	int animate = 0;
-	int animate_stagger = 0;
 	gint count = 1;
 
 	/* Stuff to do if this is a ``real'' move */
@@ -204,9 +206,6 @@ gint move_board(gint8 board[8][8], guint x, guint y, guint me, gint real)
 
 		move_count++;
 
-		animate = gnome_config_get_int("/gnothello/Preferences/animate=2");
-		animate_stagger = gnome_config_get_int("/gnothello/Preferences/animstagger=0");
-
 		if(whose_turn == WHITE_TURN) {
 			whose_turn = BLACK_TURN;
 			gui_message(_("Dark's move"));
@@ -444,9 +443,6 @@ gint computer_move_1(guint me)
 	guint num_moves = 0;
 	guint i, j;
 
-	if(whose_turn != me)
-		return(FALSE);
-
 	for(i = 0; i < 8; i++)
 		for(j = 0; j < 8; j++)
 			if(is_valid_move(i, j, me)) {
@@ -471,9 +467,6 @@ gint computer_move_3(guint me)
 	gint tmp_move;
 	gint8 tboard[8][8];
 
-	if(whose_turn != me)
-		return(FALSE);
-
 	for(i = 0; i < 8; i++)
 		for(j = 0; j < 8; j++)
 			if(is_valid_move(i, j, me)) {
@@ -517,9 +510,6 @@ gint flip_final_results()
 	guint white_pieces;
 	guint black_pieces;
 	guint adder = 0;
-	guint animate_stagger;
-
-	animate_stagger = gnome_config_get_int("/gnothello/Preferences/animstagger=0");
 
 	white_pieces = count_pieces(WHITE_TURN);
 	black_pieces = count_pieces(BLACK_TURN);
@@ -623,7 +613,9 @@ gint check_valid_moves()
 			gui_message(_("The game was a draw."));
 		whose_turn = 0;
 		game_in_progress = 0;
-		flip_final_id = gtk_timeout_add(3000, flip_final_results, NULL);
+		if (flip_final)
+			flip_final_id = gtk_timeout_add(3000,
+					flip_final_results, NULL);
 		return(TRUE);
 	}
 
