@@ -108,13 +108,6 @@ void score_cb(GtkWidget *, gpointer);
 void hint_cb(GtkWidget *, gpointer);
 void solve_cb(GtkWidget *, gpointer);
 
-GnomeUIInfo file_menu[] = {
-
-  GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
-
-  GNOMEUIINFO_END
-};
-
 GnomeUIInfo game_menu[] = {
   GNOMEUIINFO_MENU_NEW_GAME_ITEM(new_game_cb, NULL),
 
@@ -132,6 +125,10 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_MENU_SCORES_ITEM(score_cb, NULL),
 
+  GNOMEUIINFO_SEPARATOR,
+
+  GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
+
   GNOMEUIINFO_END
 };
 
@@ -182,7 +179,6 @@ GnomeUIInfo settings_menu[] = {
 };
 
 GnomeUIInfo main_menu[] = {
-  GNOMEUIINFO_MENU_FILE_TREE(file_menu),
   GNOMEUIINFO_MENU_GAME_TREE(game_menu),
   GNOMEUIINFO_SUBTREE(N_("_Move"), move_menu),
   GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
@@ -447,10 +443,10 @@ int setup_mover(int x,int y,int status){
       paused = 1;
       gtk_clock_stop(GTK_CLOCK(timer));
       if(!have_been_hinted){
-	message("Puzzle solved! Well done!");
+	message(_("Puzzle solved! Well done!"));
 	game_score();
       } else {
-	message("Puzzle solved!");
+	message(_("Puzzle solved!"));
       }
     }
     return 1;
@@ -743,7 +739,7 @@ void pause_cb(){
   if(game_over()) return;
   paused = !paused;
   if(paused){
-    message("... Game paused ...");
+    message(_("... Game paused ..."));
     gtk_clock_stop(GTK_CLOCK(timer));
   } else {
     message("");
